#
# Copyright (c) 2003 Gilles Lenfant
# All rights reserved. Written by Gilles Lenfant <glenfant@bigfoot.com>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products
#    derived from this software without specific prior written permission
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

"""This is the EpozFile Product for Zope
You can use it just as you use File objects.
If Epoz is installed, an additional tab provides edition capabilities
when the content type is text/html
"""
from Globals import DTMLFile
from OFS.Image import File
from AccessControl import ClassSecurityInfo
from AccessControl.Permissions import change_images_and_files
from DateTime import DateTime

def manage_addEpozFile(container, id, REQUEST=None):
    """Creates an EpozFile in the container
    """
    o = EpozFile(id, '', '', content_type='text/html', precondition='')
    container._setObject(id, o)
    if REQUEST:
        REQUEST['RESPONSE'].redirect(container.absolute_url()+('/%s/manage_main' % id))
    return

manage_addEpozFileForm = DTMLFile('zmi/addEpozFileForm', globals())

class EpozFile(File):
    """An EpozFile provides the same features as an usual File. In addition, you
    can edit its content with Epoz if its content_type is text/html
    """

    meta_type = 'EpozFile'

    security = ClassSecurityInfo()
    
    def manage_options(self):
        """Builds manage tabs depending on Epoz installation and content_type
        """
        fileOptions = File.manage_options
        try:
            from Products import Epoz
            fileOptions = File.manage_options
            if self.content_type == 'text/html':
                options = (fileOptions[:1]
                           + ({'label': 'Epoz', 'action': 'manage_epozForm'},)
                           + fileOptions[1:])
            else:
                options = fileOptions
        except ImportError, e:
            options = fileOptions
        return options
    
    manage_epozForm = DTMLFile('zmi/manage_epozForm', globals())

    security.declareProtected(change_images_and_files, 'manage_epoz')
    def manage_epoz(self, title, content_type, filedata=None, REQUEST=None):
        """Content changed from Epoz tab
        """
        self.manage_edit(title, content_type, filedata=filedata)
        if REQUEST:
            message="Saved changes."
            return self.manage_epozForm(self,REQUEST,manage_tabs_message=message, management_view='Epoz')

    security.declareProtected(change_images_and_files, 'manage_widgetdims')
    def manage_widgetdims(self, REQUEST):
        """Change dimensions of widget
        """
        change = REQUEST.form['manage_widgetdims']
        rules = {
            'Taller': ('__epozfile_height__', 200, 50),
            'Shorter': ('__epozfile_height__', 200, -50),
            'Wider': ('__epozfile_width__', 400, 50),
            'Narrower': ('__epozfile_width__', 400, -50)}
        cookieName, defaultSize, add = rules[change]
        expires = (DateTime('GMT') + 365).rfc822()
        size = REQUEST.get(cookieName, str(defaultSize))
        size = str(int(size) + add)
        REQUEST.RESPONSE.setCookie(cookieName, size, path='/', expires=expires)
        message="Widget " + change.lower()
        return self.manage_epozForm(self,REQUEST,manage_tabs_message=message, management_view='Epoz')

def initialize(context):
    """Registers this Product into Zope
    """
    context.registerClass(
        instance_class = EpozFile,
        permission='Add EpozFile',
        constructors=(manage_addEpozFileForm, manage_addEpozFile),
        icon='www/EpozFile_icon.gif')

    return
